
# Type: genome build


TODO

URI: [biolink:genome_build](https://w3id.org/biolink/vocab/genome_build)


## Domain and Range

[NamedThing](NamedThing.md) ->  <sub>OPT</sub> [String](types/String.md)

## Parents

 *  is_a: [node property](node_property.md)

## Children


## Used by

 * [GenomicSequenceLocalization](GenomicSequenceLocalization.md)
